@@ -1,29 +1,15 @@
 #
-# DESCRIPTION
+# DESCRIPTION:
 #   PerlORM - Object relational mapper (ORM) for Perl. PerlORM is Perl
 #   library that implements object-relational mapping. Its features are
 #   much similar to those of Java's Hibernate library, but interface is
 #   much different and easier to use.
 #
-# AUTHOR
+# AUTHOR:
 #   Alexey V. Akimov <akimov_alexey@sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2005-2006 Alexey V. Akimov
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2.1 of the License, or (at your option) any later version.
-#   
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#   
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#   Copyright (c) 2005 Alexey V. Akimov. All rights reserved.
 #
 
 package ORM::Db::DBI::SQLite;
@@ -156,13 +142,11 @@ sub table_struct
         {
             if( $row =~ /^\s*([^\s]+)\s+([^\s]+)(.*?\s+default (NULL|\'[^\']*\'))?/i )
             {
-            	last if $1 =~ /PRIMARY|UNIQUE|CHECK/;
                 my $name = $1;
                 my $type = $2;
                 my $def  = $4;
 
                 $name = $1 if( $name =~ /^\[(.+)\]$/ );
-                $name = $2 if( $name =~ /^(['"])(.+)\1$/ );
 
                 if( ! defined $def )
                 {
@@ -193,7 +177,7 @@ sub table_struct
         $res = $self->select
         (
             error => $error,
-            query => 'SELECT * FROM '.$self->qt('_ORM_refs').' WHERE class='.$self->qc( $arg{class} ),
+            query => 'SELECT * FROM _ORM_refs WHERE class='.$self->qc( $arg{class} ),
         );
         unless( $error->fatal )
         {
@@ -207,7 +191,7 @@ sub table_struct
         }
     }
 
-    $error->upto( $arg{error} );
+    $arg{error} && $arg{error}->add( error=>$error );
     return \%field, \%defaults;
 }
 
@@ -225,3 +209,4 @@ sub _lost_connection
 ## SQL FUNCTIONS
 ##
 
+sub _func_concat        { shift; ORM::Filter::Cmp->new( '||', @_ ); }
